#include "imagegallerymodel.h"
#include <QDir>
#include <QFile>
#include <QFileSystemWatcher>

ImageGalleryModel::ImageGalleryModel(QObject *parent) :
    QStandardItemModel(parent)
{
    watcher = new QFileSystemWatcher(this);
    connect(watcher, SIGNAL(directoryChanged(QString)),
            this, SLOT(onDirectoryChanged(QString)));
}


QHash<int, QByteArray> ImageGalleryModel::roleNames() const
{
    QHash<int, QByteArray> roles;
    roles[PathRole] = "path";
    return roles;
}

void ImageGalleryModel::setRootPath(const QString &p)
{
    this->clear();

    if (path != "")
    {
        watcher->removePath(path);
    }

    path = p;
    watcher->addPath(path);

    // Sync the model
    onDirectoryChanged(path);

}

void ImageGalleryModel::onDirectoryChanged(const QString &path)
{
    QStringList nameFilters;
    nameFilters << "*.png" << "*.jpg";
    QDir directory(path);
    directory.setNameFilters(nameFilters);
    QStringList files = directory.entryList();

    // Sync the model with the list.

    // Add anything to the model that's on disk and not in the model
    foreach(const QString &file, files)
    {
        QString absolutePath = directory.absoluteFilePath(file);
        bool found = false;
        for(int i = 0; i < rowCount(); i++)
        {
            if (data(index(i, 0), PathRole).toString() == absolutePath)
            {
                found = true;
                break;
            }
        }
        if (!found)
        {
            QStandardItem *item = new QStandardItem();
            item->setData(absolutePath, PathRole);
            appendRow(item);
        }
    }


    // Now delete anything in the model not on the filesystem
    for(int i = 0; i < rowCount(); i++)
    {
        QString name = directory.relativeFilePath(data(index(i, 0), PathRole).toString());
        if (!files.contains(name))
        {
            removeRow(i);
            i--;
        }
    }
}
